@@ -203,7 +203,7 @@ class BaseKempObject(HttpClient, AccessInfoMixin):
 
     def save(self, update=False):
         if not update:
-            response = self._get(self._API_ADD, self._get_base_parameters())
+            response = self._get(self._API_ADD, self.to_api_dict())
         else:
             response = self._get(self._API_MOD, self.to_api_dict())
 
